macro_rules! directory_path {
() => { ... };
($name:expr) => { ... };
}Expand description
directory_path returns the path to the parent directory of the calling test file, if called with an argument then calls iocore::Path::join on the directory path (creates directory if necessary)