macro_rules! folder_path {
() => { ... };
($name:expr) => { ... };
}Expand description
folder_path returns the path to the parent folder of the calling test file, if called with an argument then calls iocore::Path::join on the folder path (creates folder if necessary)