macro_rules! path_to_test_folder {
() => { ... };
($name:expr $(,)?) => { ... };
}Expand description
path_to_test_file returns the path to a test directory as the test file
macro_rules! path_to_test_folder {
() => { ... };
($name:expr $(,)?) => { ... };
}path_to_test_file returns the path to a test directory as the test file