Macro test_folder_parent_path

macro_rules! test_folder_parent_path {
    ($name:expr) => { ... };
}
test_folder_parent_path returns the parent folder of the test file which calls it joined with the given “name” (creates the directory if necessary)